@@ -1,7 +1,7 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2014
 #
-`logLik.mvmeta` <-
+logLik.mvmeta <-
 function(object, ...) {
 #
 ################################################################################
@@ -11,6 +11,6 @@ function(object, ...) {
 #
   class(val) <- "logLik"
 #
-  return(val)
+  val
 }
 
