@@ -1,11 +1,11 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2014
 #
-`vcov.mvmeta` <-
+vcov.mvmeta <-
 function(object, ...) {
 #
 ################################################################################
 #
-  return(object$vcov)
+  object$vcov
 }
 
